@@ -54,6 +54,7 @@ globalVariables(c(".",
                   "index",
                   "input",
                   "Interpretation",
+                  "interpretation",
                   "item",
                   "key_ab",
                   "key_ab_lag",
@@ -89,6 +90,7 @@ globalVariables(c(".",
                   "package_v",
                   "Pasted",
                   "patient_id",
+                  "pattern",
                   "phylum",
                   "plural",
                   "prevalence",
